@@ -50,6 +50,7 @@ create_marker (ShumateDemoWindow *self, double lat, double lng)
 {
   GtkWidget *image = gtk_image_new_from_icon_name ("map-marker-symbolic");
   ShumateMarker *marker = shumate_marker_new ();
+  gtk_widget_set_valign (GTK_WIDGET (marker), GTK_ALIGN_END);
 
   shumate_location_set_location (SHUMATE_LOCATION (marker), lat, lng);
   shumate_marker_set_child (marker, image);
@@ -67,20 +68,22 @@ on_symbol_clicked (ShumateVectorRenderer *renderer,
   const char *name = shumate_symbol_event_get_tag (event, "name");
 
   if (name != NULL)
-    g_print ("Symbol %s (%s) clicked in layer %s (%s) at (%f, %f)\n",
+    g_print ("Symbol %s (%s) clicked in layer %s (%s) at (%f, %f), click %d\n",
              shumate_symbol_event_get_feature_id (event),
              name,
              shumate_symbol_event_get_layer (event),
               shumate_symbol_event_get_source_layer (event),
              shumate_location_get_latitude (SHUMATE_LOCATION (event)),
-             shumate_location_get_longitude (SHUMATE_LOCATION (event)));
+             shumate_location_get_longitude (SHUMATE_LOCATION (event)),
+             shumate_symbol_event_get_n_press (event));
   else
-    g_print ("Symbol %s clicked in layer %s (%s) at (%f, %f)\n",
+    g_print ("Symbol %s clicked in layer %s (%s) at (%f, %f), click %d\n",
              shumate_symbol_event_get_feature_id (event),
              shumate_symbol_event_get_layer (event),
               shumate_symbol_event_get_source_layer (event),
              shumate_location_get_latitude (SHUMATE_LOCATION (event)),
-             shumate_location_get_longitude (SHUMATE_LOCATION (event)));
+             shumate_location_get_longitude (SHUMATE_LOCATION (event)),
+             shumate_symbol_event_get_n_press (event));
 }
 
 
